@@ -32,14 +32,16 @@ class Client:
 
     DEFAULT_ENDPOINT = 'http://localhost:8080'
 
-    def __init__(self, endpoint=None, key=None, secret=None, token=None, username=None, password=None, timeout=5.0, ssl_verify=True, headers=None, debug=False):
+    def __init__(self, endpoint=None, key=None, secret=None, token=None, username=None, password=None, timeout=5.0,
+                 ssl_verify=True, ssl_cert=None, ssl_key=None, headers=None, debug=False):
         self.endpoint = endpoint or os.environ.get('ALERTA_ENDPOINT', self.DEFAULT_ENDPOINT)
 
         if debug:
             HTTPConnection.debuglevel = 1
 
         key = key or os.environ.get('ALERTA_API_KEY', '')
-        self.http = HTTPClient(self.endpoint, key, secret, token, username, password, timeout, ssl_verify, headers, debug)
+        self.http = HTTPClient(self.endpoint, key, secret, token, username, password,
+                               timeout, ssl_verify, ssl_cert, ssl_key, headers, debug)
 
     # Alerts
     def send_alert(self, resource, event, **kwargs):
@@ -166,7 +168,8 @@ class Client:
         return self.http.delete('/alert/{}/note/{}'.format(id, note_id))
 
     # Blackouts
-    def create_blackout(self, environment, service=None, resource=None, event=None, group=None, tags=None, customer=None, start=None, duration=None, text=None):
+    def create_blackout(self, environment, service=None, resource=None, event=None, group=None, tags=None,
+                        origin=None, customer=None, start=None, duration=None, text=None):
         data = {
             'environment': environment,
             'service': service or list(),
@@ -174,6 +177,7 @@ class Client:
             'event': event,
             'group': group,
             'tags': tags or list(),
+            'origin': origin,
             'customer': customer,
             'startTime': start,
             'duration': duration,
@@ -198,6 +202,7 @@ class Client:
             'event': kwargs.get('event'),
             'group': kwargs.get('group'),
             'tags': kwargs.get('tags'),
+            'origin': kwargs.get('origin'),
             'startTime': kwargs.get('startTime'),
             'endTime': kwargs.get('endTime'),
             'text': kwargs.get('text'),
@@ -349,7 +354,7 @@ class Client:
         r = self.http.post('/user', data)
         return User.parse(r['user'])
 
-    def get_user(self):
+    def get_user(self, id):
         return User.parse(self.http.get('/user/%s' % id)['user'])
 
     def get_user_groups(self, id):
@@ -513,7 +518,21 @@ class HTTPClient:
     DEFAULT_PAGE_NUMBER = 1
     DEFAULT_PAGE_SIZE = 50
 
-    def __init__(self, endpoint, key=None, secret=None, token=None, username=None, password=None, timeout=30.0, ssl_verify=True, headers=None, debug=False):
+    def __init__(
+        self,
+        endpoint,
+        key=None,
+        secret=None,
+        token=None,
+        username=None,
+        password=None,
+        timeout=30.0,
+        ssl_verify=True,
+        ssl_cert=None,
+        ssl_key=None,
+        headers=None,
+        debug=False,
+    ):
         self.endpoint = endpoint
         self.auth = None
 
@@ -530,6 +549,9 @@ class HTTPClient:
         self.session = requests.Session()
         self.session.verify = ssl_verify  # or use REQUESTS_CA_BUNDLE env var
 
+        if ssl_cert:
+            self.session.cert = (ssl_cert, ssl_key)
+
         self.headers = headers or dict()
         merge(self.headers, self.default_headers())
 
