@@ -5,7 +5,7 @@ from alertaclient.utils import action_progressbar, build_query
 
 @click.command('action', short_help='Action alerts')
 @click.option('--action', '-a', metavar='ACTION', help='Custom action (user-defined)')
-@click.option('--ids', '-i', metavar='UUID', multiple=True, help='List of alert IDs (can use short 8-char id)')
+@click.option('--ids', '-i', metavar='ID', multiple=True, help='List of alert IDs (can use short 8-char id)')
 @click.option('--query', '-q', 'query', metavar='QUERY', help='severity:"warning" AND resource:web')
 @click.option('--filter', '-f', 'filters', metavar='FILTER', multiple=True, help='KEY=VALUE eg. serverity=warning resource=web')
 @click.option('--text', help='Message associated with action')
