@@ -9,8 +9,8 @@ from alertaclient.utils import origin
 
 @click.command('heartbeats', short_help='List heartbeats')
 @click.option('--alert', is_flag=True, help='Alert on stale or slow heartbeats')
-@click.option('--severity', '-s', metavar='SEVERITY', default='major', help='Severity for stale heartbeat alerts')
-@click.option('--timeout', metavar='SECONDS', default=86000, type=int, help='Seconds before stale heartbeat alerts will be expired')
+@click.option('--severity', '-s', metavar='SEVERITY', default='major', help='Severity for heartbeat alerts')
+@click.option('--timeout', metavar='SECONDS', type=int, help='Seconds before stale heartbeat alerts will be expired')
 @click.option('--purge', is_flag=True, help='Delete all stale heartbeats')
 @click.pass_obj
 def cli(obj, alert, severity, timeout, purge):
@@ -22,6 +22,16 @@ def cli(obj, alert, severity, timeout, purge):
     except KeyError:
         default_normal_severity = 'normal'
 
+    if severity in ['normal', 'ok', 'cleared']:
+        raise click.UsageError('Must be a non-normal severity. "{}" is one of {}'.format(
+            severity, ', '.join(['normal', 'ok', 'cleared']))
+        )
+
+    if severity not in obj['alarm_model']['severity'].keys():
+        raise click.UsageError('Must be a valid severity. "{}" is not one of {}'.format(
+            severity, ', '.join(obj['alarm_model']['severity'].keys()))
+        )
+
     if obj['output'] == 'json':
         r = client.http.get('/heartbeats')
         heartbeats = [Heartbeat.parse(hb) for hb in r['heartbeats']]
@@ -46,20 +56,20 @@ def cli(obj, alert, severity, timeout, purge):
         with click.progressbar(heartbeats, label='Alerting {} heartbeats'.format(len(heartbeats))) as bar:
             for b in bar:
 
-                environment = b.attributes.pop('environment', 'Production')
-                service = b.attributes.pop('service', ['Alerta'])
-                group = b.attributes.pop('group', 'System')
+                want_environment = b.attributes.pop('environment', 'Production')
+                want_severity = b.attributes.pop('severity', severity)
+                want_service = b.attributes.pop('service', ['Alerta'])
+                want_group = b.attributes.pop('group', 'System')
 
                 if b.status == 'expired':  # aka. "stale"
-                    severity = b.attributes.pop('severity', severity)
                     client.send_alert(
                         resource=b.origin,
                         event='HeartbeatFail',
-                        environment=environment,
-                        severity=severity,
+                        environment=want_environment,
+                        severity=want_severity,
                         correlate=['HeartbeatFail', 'HeartbeatSlow', 'HeartbeatOK'],
-                        service=service,
-                        group=group,
+                        service=want_service,
+                        group=want_group,
                         value='{}'.format(b.since),
                         text='Heartbeat not received in {} seconds'.format(b.timeout),
                         tags=b.tags,
@@ -70,15 +80,14 @@ def cli(obj, alert, severity, timeout, purge):
                         customer=b.customer
                     )
                 elif b.status == 'slow':
-                    severity = b.attributes.pop('severity', severity)
                     client.send_alert(
                         resource=b.origin,
                         event='HeartbeatSlow',
-                        environment=environment,
-                        severity=severity,
+                        environment=want_environment,
+                        severity=want_severity,
                         correlate=['HeartbeatFail', 'HeartbeatSlow', 'HeartbeatOK'],
-                        service=service,
-                        group=group,
+                        service=want_service,
+                        group=want_group,
                         value='{}ms'.format(b.latency),
                         text='Heartbeat took more than {}ms to be processed'.format(b.max_latency),
                         tags=b.tags,
@@ -89,15 +98,14 @@ def cli(obj, alert, severity, timeout, purge):
                         customer=b.customer
                     )
                 else:
-                    severity = b.attributes.pop('severity', default_normal_severity)
                     client.send_alert(
                         resource=b.origin,
                         event='HeartbeatOK',
-                        environment=environment,
-                        severity=severity,
+                        environment=want_environment,
+                        severity=default_normal_severity,
                         correlate=['HeartbeatFail', 'HeartbeatSlow', 'HeartbeatOK'],
-                        service=service,
-                        group=group,
+                        service=want_service,
+                        group=want_group,
                         value='',
                         text='Heartbeat OK',
                         tags=b.tags,
