@@ -4,15 +4,30 @@ from alertaclient.utils import build_query
 
 
 @click.command('note', short_help='Add note')
-@click.option('--ids', '-i', metavar='UUID', multiple=True, help='List of note IDs')
-@click.option('--alert-ids', '-i', metavar='UUID', multiple=True, help='List of alert IDs (can use short 8-char id)')
+@click.option('--alert-ids', '-i', metavar='ID', multiple=True, help='List of alert IDs (can use short 8-char id)')
 @click.option('--query', '-q', 'query', metavar='QUERY', help='severity:"warning" AND resource:web')
 @click.option('--filter', '-f', 'filters', metavar='FILTER', multiple=True, help='KEY=VALUE eg. serverity=warning resource=web')
 @click.option('--text', help='Note or message')
-@click.option('--delete', '-D', metavar='ID', nargs=2, help='Delete note parent ID and note ID')
+@click.option('--delete', '-D', metavar='ID', nargs=2, help='Delete note, using alert ID and note ID')
 @click.pass_obj
-def cli(obj, ids, alert_ids, query, filters, text, delete):
-    """Add or delete note to alerts."""
+def cli(obj, alert_ids, query, filters, text, delete):
+    """
+    Add or delete note to alerts.
+
+    EXAMPLES
+
+        Add a note to an alert.
+
+            $ alerta note --alert-ids <alert-id> --text <note>
+
+        List notes for an alert.
+
+            $ alerta notes --alert-ids <alert-id>
+
+        Delete a note for an alert.
+
+            $ alerta note -D <alert-id> <note-id>
+    """
     client = obj['client']
     if delete:
         client.delete_alert_note(*delete)
