@@ -22,7 +22,7 @@ def cli(obj, name, email, password, status, text):
     try:
         r = client.signup(name=name, email=email, password=password, status=status, attributes=None, text=text)
     except Exception as e:
-        click.echo('ERROR: {}'.format(e))
+        click.echo('ERROR: {}'.format(e), err=True)
         sys.exit(1)
     if 'token' in r:
         click.echo('Signed Up.')
