@@ -10,7 +10,8 @@ class AlertTestCase(unittest.TestCase):
 
     def test_blackout(self):
         blackout = self.client.create_blackout(
-            environment='Production', service=['Web', 'App'], resource='web01', event='node_down', group='Network', tags=['london', 'linux']
+            environment='Production', service=['Web', 'App'], resource='web01', event='node_down', group='Network',
+            tags=['london', 'linux'], origin='foo/bar'
         )
         blackout_id = blackout.id
 
@@ -18,14 +19,17 @@ class AlertTestCase(unittest.TestCase):
         self.assertEqual(blackout.service, ['Web', 'App'])
         self.assertIn('london', blackout.tags)
         self.assertIn('linux', blackout.tags)
+        self.assertEqual(blackout.origin, 'foo/bar')
 
-        blackout = self.client.update_blackout(blackout_id, environment='Development', group='Network', text='updated blackout')
+        blackout = self.client.update_blackout(blackout_id, environment='Development', group='Network',
+                                               origin='foo/quux', text='updated blackout')
         self.assertEqual(blackout.environment, 'Development')
         self.assertEqual(blackout.group, 'Network')
+        self.assertEqual(blackout.origin, 'foo/quux')
         self.assertEqual(blackout.text, 'updated blackout')
 
         blackout = self.client.create_blackout(
-            environment='Production', service=['Core'], group='Network'
+            environment='Production', service=['Core'], group='Network', origin='foo/baz'
         )
 
         blackouts = self.client.get_blackouts()
